/* Dark color scheme */
@define-color theme_base_color #333333;
@define-color theme_bg_color #393f3f;
@define-color theme_selected_bg_color #3465a4;
@define-color theme_text_color #eeeeec;
@define-color theme_fg_color @theme_text_color;
@define-color theme_selected_fg_color @theme_text_color;

@define-color placeholder_text_color shade(@theme_text_color, 0.4);

@define-color theme_unfocused_base_color @theme_base_color;
@define-color theme_unfocused_text_color mix(@theme_unfocused_base_color, @theme_text_color, 0.8);
@define-color theme_unfocused_fg_color mix(@theme_unfocused_bg_color, @theme_text_color, 0.3);
@define-color theme_unfocused_bg_color @theme_bg_color;
@define-color theme_unfocused_selected_bg_color @unfocused_borders;
@define-color theme_unfocused_selected_fg_color @theme_selected_fg_color;
@define-color unfocused_button_background @theme_unfocused_bg_color;
@define-color unfocused_borders mix(@theme_unfocused_bg_color, @theme_text_color, 0.15);
@define-color unfocused_insensitive_borders mix(@theme_unfocused_bg_color, @unfocused_borders, 0.5);
@define-color unfocused_insensitive_fg_color mix(@insensitive_fg_color, @insensitive_bg_color, 0.3);
@define-color unfocused_insensitive_bg_color @insensitive_bg_color;
@define-color unfocused_dark_bg mix(@theme_unfocused_bg_color, @borders, 0.5);

@define-color menu_bg_color #555753;
@define-color menu_fg_color @theme_text_color;

@define-color menu_controls_color #aaa8ac;

@define-color menu_combobox_border darker (@theme_selected_bg_color);
@define-color menu_separator mix (@menu_fg_color, @menu_bg_color, 0.95);

@define-color inactive_frame_color shade (@theme_bg_color, 0.8);

@define-color sidebar_bg shade (@theme_bg_color, 1.02);
@define-color sidebar_bg_unfocused mix(@sidebar_bg, @theme_unfocused_base_color, 0.5);

@define-color sidebar_scrollbar_trough shade(@sidebar_bg, 1.25);
@define-color sidebar_scrollbar_trough_backdrop shade(@sidebar_bg_unfocused, 1.2);

@define-color button_gradient_color_a shade (@theme_bg_color, 1.15);
@define-color button_gradient_color_b @theme_bg_color;
@define-color button_gradient_color_c shade (@theme_bg_color, 0.8);
@define-color borders #24282a;

@define-color button_active_gradient_color_a shade (@button_gradient_color_b, 0.7);
@define-color button_active_gradient_color_b shade (@button_gradient_color_a, 0.7);
@define-color button_active_text @theme_text_color;
@define-color button_active_text_shadow alpha(black, 0.6);
@define-color button_text_shadow alpha(black, 0.7);

@define-color button_hover_gradient_color_a shade (@button_gradient_color_a, 1.10);
@define-color button_hover_gradient_color_b shade (@button_gradient_color_b, 1.02);

@define-color insensitive_fg_color #535555;
@define-color insensitive_bg_color mix(@theme_bg_color, @theme_base_color, 0.6);
@define-color insensitive_borders @borders;
@define-color insensitive_scale_borders @insensitive_fg_color;

@define-color trough_bg_color_a #30312f;
@define-color trough_bg_color_b #41433f;

@define-color infobar_bg_color shade(rgb (138, 173, 212), 0.8);

@define-color scrollbar_trough shade(@theme_bg_color, 1.2);
@define-color scrollbar_trough_insensitive shade(@theme_bg_color, 1.05); /* FIXME */
@define-color scrollbar_trough_unfocused shade(@theme_unfocused_bg_color, 1.2);
@define-color scrollbar_slider mix(@scrollbar_trough, @theme_fg_color, 0.15);
@define-color scrollbar_slider_prelight mix(@scrollbar_trough, @theme_fg_color, 0.3);
@define-color scrollbar_slider_active @theme_selected_bg_color;
@define-color scrollbar_slider_insensitive alpha(black, 0); /* FIXME should be transparent */
@define-color scrollbar_slider_unfocused shade(@theme_unfocused_base_color, 0.8);

@define-color switch_slider_color shade(@theme_bg_color, 0.9);
@define-color switch_trough_active_color @theme_text_color;
@define-color switch_trough_active_bg_a shade(@theme_selected_bg_color, 0.6);
@define-color switch_trough_active_bg_b @theme_selected_bg_color;

@define-color progressbar_background_a shade(@theme_selected_bg_color, 1.15);
@define-color progressbar_background_b shade(@theme_selected_bg_color, 0.8);
@define-color progressbar_pattern @progressbar_background_b;
@define-color progressbar_border shade(@switch_trough_active_bg_a, 0.60);
@define-color progressbar_unfocused_background @unfocused_borders;
@define-color progressbar_unfocused_border @theme_unfocused_fg_color;
@define-color progressbar_unfocused_trough @unfocused_dark_bg;

@define-color entry_text_color #ffffff;
@define-color entry_background_a shade(@theme_base_color, 0.85);
@define-color entry_background_b @theme_base_color;

@define-color entry_inset alpha(black, 0.15);

@define-color internal_element_color #595959;
@define-color internal_element_prelight #eeeeee;
@define-color internal_element_insensitive mix(@internal_element_color, @theme_base_color, 0.65);

@define-color scale_trough_bg_a shade(@borders, 1.15);
@define-color scale_trough_bg_b shade(@theme_bg_color, 0.95);
@define-color scale_shadow shade(@theme_bg_color, 1.08);
@define-color scale_progress_fill #2c85e2;
@define-color scale_highlight_border #182f4c;
@define-color scale_highlight_bg #356599;
@define-color scale_highlight_shadow alpha(white, 0.20);

@define-color notebook_active_tab_border shade(@theme_selected_bg_color, 0.95);
@define-color notebook_selected_tab_color alpha(@theme_selected_bg_color, 0.75);

@define-color notebook_tab_gradient_a shade(@theme_bg_color, 0.8);
@define-color notebook_tab_gradient_b shade(@theme_bg_color, 0.75);
@define-color notebook_tab_hilight shade(@theme_bg_color, 0.9);

@define-color toolbar_gradient_a shade(@theme_bg_color, 0.77);
@define-color toolbar_gradient_b shade(@theme_bg_color, 0.8);
@define-color toolbar_gradient_c shade(@theme_bg_color, 0.86);

@define-color toolbar_active_button_color #222222;
@define-color toolbar_button_prelight alpha(black, 0.3);
@define-color toolbar_separator shade(@internal_element_color, 0.90);

@define-color primary_toolbar_button_text_shadow alpha(black, 0.1);

@define-color content_view_bg #242424;
@define-color list_box_bg @theme_base_color;

@define-color app_notification_a #343a3b;
@define-color app_notification_b #3b3e3f;
@define-color app_notification_c #343a3b;

@define-color app_notification_border #555357;

@define-color suggested_action_button_a #407cbc;
@define-color suggested_action_button_b #2a5285;
@define-color suggested_action_button_border #204a87;
@define-color suggested_action_button_fg #ffffff;
@define-color suggested_action_button_shadow transparent;

@define-color treeview_focus_border shade (@theme_selected_bg_color, 1.20);

@define-color view_separators @toolbar_separator;
@define-color view_symbolic_color shade(@theme_text_color, 0.70);

@define-color expander_row_selected_color alpha (@theme_base_color, 0.60);

@define-color inset_light_color alpha(white, 0.05);
@define-color inset_dark_color alpha(black, 0.25);

/**************************
 * Selection Mode classes *
 **************************/
@define-color selection_toolbar_bg_a #3465a4;
@define-color selection_toolbar_bg_b #1d437b;
@define-color selection_toolbar_bg_backdrop @selection_toolbar_bg_b;
@define-color selection_toolbar_fg #729fcf;
@define-color selection_toolbar_shadow #204a87;
@define-color selection_toolbar_border #183967;

@define-color selection_toolbar_button_a @selection_toolbar_fg;
@define-color selection_toolbar_button_b @selection_toolbar_bg_a;
@define-color selection_toolbar_button_fg #bfbfbf;
@define-color selection_toolbar_button_border #23446f;
@define-color selection_toolbar_button_border_backdrop shade(@selection_toolbar_button_border, 0.80);
@define-color selection_toolbar_button_shadow alpha(black, 0.30);

@define-color selection_toolbar_suggested_button_a #3e4545;
@define-color selection_toolbar_suggested_button_b #2e3232;
@define-color selection_toolbar_suggested_button_c #2a2828;
@define-color selection_toolbar_suggested_button_fg #ffffff;
@define-color selection_toolbar_suggested_button_border #1f2020;
@define-color selection_toolbar_suggested_button_border_backdrop shade(@selection_toolbar_suggested_button_border, 1.30);

@define-color selection_menu_fg @selection_toolbar_fg;
@define-color selection_menu_hover shade(@selection_menu_fg, 1.15);
@define-color selection_menu_active shade(@selection_menu_fg, 1.30);

/**************
 * GNOME Apps *
 **************/
@define-color entry_tag_bg #888a85;
@define-color entry_tag_fg black;

/******
 * WM *
 ******/
@define-color wm_title @theme_fg_color;
@define-color wm_unfocused_title @theme_unfocused_fg_color;
@define-color wm_highlight shade(@theme_bg_color, 1.4);
@define-color wm_title_highlight_dark @button_text_shadow;
@define-color wm_title_highlight alpha(#000000, 0.0);
@define-color wm_title_shadow @wm_title_highlight_dark;

@define-color wm_bg_a shade (@theme_bg_color, 1.3);
@define-color wm_bg_b @theme_bg_color;

@define-color wm_shadow alpha(black, 0.7);

@define-color wm_button_bg_a shade (@theme_bg_color, 1.0);
@define-color wm_button_bg_b shade (@theme_bg_color, 0.85);
@define-color wm_button_bg_c shade (@theme_bg_color, 0.8);
@define-color wm_button_bg_d shade (@theme_bg_color, 0.9);

@define-color wm_button_bg_hover_a shade (@wm_button_bg_a, 1.2);
@define-color wm_button_bg_hover_b shade (@wm_button_bg_b, 1.2);
@define-color wm_button_bg_hover_c shade (@wm_button_bg_c, 1.2);
@define-color wm_button_bg_hover_d shade (@wm_button_bg_d, 1.2);

@define-color wm_button_bg_active_a shade (@theme_bg_color, 0.5);
@define-color wm_button_bg_active_b shade (@theme_bg_color, 0.7);
@define-color wm_button_bg_active_c shade (@theme_bg_color, 0.7);

@import url("gtk-main-common.css");
@import url("gtk-widgets-backgrounds.css");
@import url("gtk-widgets-borders-dark.css");
@import url("gtk-widgets-assets-dark.css");
@import url("gtk-widgets.css");
@import url("gtk-widgets-dark-overrides.css");
@import url("gnome-applications.css");
@import url("gnome-applications-dark-overrides.css");
